"use strict";
// Copyright (c) Aptos
// SPDX-License-Identifier: Apache-2.0
Object.defineProperty(exports, "__esModule", { value: true });
const faucet_client_1 = require("./faucet_client");
const aptos_account_1 = require("./aptos_account");
const aptos_client_1 = require("./aptos_client");
const token_client_1 = require("./token_client");
const util_test_1 = require("./util.test");
test("full tutorial nft token flow", async () => {
    const client = new aptos_client_1.AptosClient(util_test_1.NODE_URL);
    const faucetClient = new faucet_client_1.FaucetClient(util_test_1.NODE_URL, util_test_1.FAUCET_URL);
    const tokenClient = new token_client_1.TokenClient(client);
    const alice = new aptos_account_1.AptosAccount();
    const bob = new aptos_account_1.AptosAccount();
    // Fund both Alice's and Bob's Account
    await faucetClient.fundAccount(alice.address(), 10000000);
    await faucetClient.fundAccount(bob.address(), 10000000);
    const collectionName = "AliceCollection";
    const tokenName = "Alice Token";
    async function ensureTxnSuccess(txnHashPromise) {
        const txnHash = await txnHashPromise;
        const txn = await client.waitForTransactionWithResult(txnHash);
        expect(txn?.success).toBe(true);
    }
    // Create collection and token on Alice's account
    await ensureTxnSuccess(tokenClient.createCollection(alice, collectionName, "Alice's simple collection", "https://aptos.dev"));
    await ensureTxnSuccess(tokenClient.createToken(alice, collectionName, tokenName, "Alice's simple token", 1, "https://aptos.dev/img/nyan.jpeg", 1000, alice.address(), 0, 0, ["key"], ["2"], ["int"]));
    const tokenId = {
        token_data_id: {
            creator: alice.address().hex(),
            collection: collectionName,
            name: tokenName,
        },
        property_version: "0",
    };
    // Transfer Token from Alice's Account to Bob's Account
    await tokenClient.getCollectionData(alice.address().hex(), collectionName);
    let aliceBalance = await tokenClient.getTokenBalanceForAccount(alice.address().hex(), tokenId);
    expect(aliceBalance.amount).toBe("1");
    const tokenData = await tokenClient.getTokenData(alice.address().hex(), collectionName, tokenName);
    expect(tokenData.name).toBe(tokenName);
    await ensureTxnSuccess(tokenClient.offerToken(alice, bob.address().hex(), alice.address().hex(), collectionName, tokenName, 1));
    aliceBalance = await tokenClient.getTokenBalanceForAccount(alice.address().hex(), tokenId);
    expect(aliceBalance.amount).toBe("0");
    await ensureTxnSuccess(tokenClient.cancelTokenOffer(alice, bob.address().hex(), alice.address().hex(), collectionName, tokenName));
    aliceBalance = await tokenClient.getTokenBalanceForAccount(alice.address().hex(), tokenId);
    expect(aliceBalance.amount).toBe("1");
    await ensureTxnSuccess(tokenClient.offerToken(alice, bob.address().hex(), alice.address().hex(), collectionName, tokenName, 1));
    aliceBalance = await tokenClient.getTokenBalanceForAccount(alice.address().hex(), tokenId);
    expect(aliceBalance.amount).toBe("0");
    await ensureTxnSuccess(tokenClient.claimToken(bob, alice.address().hex(), alice.address().hex(), collectionName, tokenName));
    const bobBalance = await tokenClient.getTokenBalanceForAccount(bob.address().hex(), tokenId);
    expect(bobBalance.amount).toBe("1");
}, 30 * 1000);
//# sourceMappingURL=token_client.test.js.map